import type { AxiosRequestConfig } from "axios";
import request, { useRequest } from "@/libs/request";

type ResponseType<T> = {
  code: number;
  data: T;
  msg: string;
  pageNum: number;
  total: number;
};

export default function requestAxios() {
  return request<any>({
    method: "get",
    url: "/api",
  });
}

class Ajax {
  static get<T>(
    url: string,
    data: { [args: string]: any },
    axiosConfig: AxiosRequestConfig = {}
  ) {
    return useRequest<ResponseType<T>>({
      method: "get",
      url,
      data,
      ...axiosConfig,
    }).content;
  }

  static post<T>(
    url: string,
    data: { [args: string]: any },
    axiosConfig: AxiosRequestConfig = {}
  ) {
    return useRequest<ResponseType<T>>({
      method: "post",
      url,
      data,
      ...axiosConfig,
    }).content;
  }

  static put<T>(
    url: string,
    data: { [args: string]: any },
    axiosConfig: AxiosRequestConfig = {}
  ) {
    return useRequest<ResponseType<T>>({
      method: "put",
      url,
      data,
      ...axiosConfig,
    }).content;
  }

  static delete<T>(
    url: string,
    data: { [args: string]: any },
    axiosConfig: AxiosRequestConfig = {}
  ) {
    return useRequest<ResponseType<T>>({
      method: "delete",
      url,
      data,
      ...axiosConfig,
    }).content;
  }
}
export const clxAjax = Ajax;
